@@ -354,6 +354,10 @@ class WorkspaceCollage(models.Model):
         snippets = list(itertools.chain(*snippets_in_groups))
         return [snippet.location for snippet in snippets]
 
+    def visible_snippet_groups(self):
+        """Return only snippet_groups that have visible snippets."""
+        return self.snippet_groups.filter(snippets__visible=True).distinct()
+
     @property
     def workspace_items(self):
         """Return workspace items used by one of our snippets."""
@@ -472,7 +476,7 @@ class WorkspaceCollageSnippetGroup(models.Model):
         Can be filtered by option restrict_to_month.
         """
         statistics = []
-        for snippet in self.snippets.all():
+        for snippet in self.snippets.filter(visible=True):
             snippet_adapter = snippet.workspace_item.adapter
 
             # Calc periods based on aggregation period setting.
@@ -541,11 +545,12 @@ class WorkspaceCollageSnippetGroup(models.Model):
         Calculates a table with each location as column, each row as
         datetime. First row consist of column names. List of lists.
 
-        Can be filtered by option restrict_to_month.
+        Can be filtered by option restrict_to_month. Only visible snippets
+        are included.
         """
         values_table = []
 
-        snippets = self.snippets.all()
+        snippets = self.snippets.filter(visible=True)
 
         # Add snippet names
         values_table.append(['Datum + tijdstip'] +
@@ -637,8 +642,13 @@ class WorkspaceCollageSnippet(models.Model):
     workspace_item = models.ForeignKey(
         WorkspaceItem)
     identifier_json = models.TextField()
+    visible = models.BooleanField(default=True)
+
     # ^^^ Format depends on workspace_item layer_method
 
+    class Meta:
+        ordering = ['name', ]
+
     def __unicode__(self):
         return u'%s' % self.name
 
