@@ -68,7 +68,10 @@ urlpatterns = patterns(
         name="lizard_map.snippet_popup"),
     url(r'^snippet/(?P<snippet_id>\d+)/edit/$',
         'lizard_map.views.snippet_edit',
-        name="lizard_map.snippet_edit"),
+        name="lizard_map_snippet_edit"),
+    url(r'^snippet/edit/',
+        'lizard_map.views.snippet_edit',
+        name="lizard_map_snippet_edit"),
     url(r'^snippet_popup/',
         'lizard_map.views.snippet_popup',
         name="lizard_map.snippet_popup"),
